==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/zh-CN/mail.php <==
<?php

return array(
    'a_user_canceled' => '用户已取消物品申请',
    'a_user_requested' => '用户已申请物品',
    'accessory_name' => '配件名称：',
    'additional_notes' => '备注：',
    'admin_has_created' => '管理员已在 :web 为您新增帐号。',
    'asset' => '资产：',
    'asset_name' => '资产名称：',
    'asset_requested' => '已申请资产',
    'asset_tag' => '资产标签：',
    'assigned_to' => '已分配给',
    'best_regards' => '此致',
    'canceled' => '已取消：',
    'checkin_date' => '交回日期：',
    'checkout_date' => '借出日期：',
    'click_to_confirm' => '请点击链接启用您在 :web 的帐号：',
    'click_on_the_link_accessory' => '请点击链接确认您已经收到配件。',
    'click_on_the_link_asset' => '请点击链接确认您已经收到资产。',
    'Confirm_Asset_Checkin' => '确认资产收回',
    'Confirm_Accessory_Checkin' => '配件签入确认',
    'Confirm_accessory_delivery' => '配件交付确认',
    'Confirm_license_delivery' => '许可证交付确认',
    'Confirm_asset_delivery' => '资产交付确认',
    'Confirm_consumable_delivery' => '耗材交付确认',
    'current_QTY' => '目前数量',
    'Days' => '天',
    'days' => '天',
    'expecting_checkin_date' => '预计归还日期：',
    'expires' => '过期',
    'Expiring_Assets_Report' => '过期资产报告',
    'Expiring_Licenses_Report' => '过期许可证报告',
    'hello' => '您好',
    'hi' => '您好',
    'i_have_read' => '我同意使用条款并确认已收到物品。',
    'item' => '项目：',
    'Item_Request_Canceled' => '已取消申领物品',
    'Item_Requested' => '已申领物品',
    'link_to_update_password' => '请点击以下链接以更新 :web 的密码：',
    'login_first_admin' => '请使用以下凭据登录新安装的 Snipe-IT：',
    'login' => '登录：',
    'Low_Inventory_Report' => '低库存报告',
    'min_QTY' => '最小数量',
    'name' => '名字',
    'new_item_checked' => '一项新物品已分配至您的名下，详细信息如下。',
    'password' => '密码',
    'password_reset' => '密码重置',

    'read_the_terms' => '请阅读以下使用条款',
    'read_the_terms_and_click' => '请阅读使用条款，点击下方链接确认您已阅读并同意使用条款，并已收到资产。',
    'requested' => '已申请',
    'reset_link' => '您的密码重置链接',
    'reset_password' => '请点击重置您的密码',
    'serial' => '序列号',
    'supplier' => '供应商',
    'tag' => '标签',
    'test_email' => 'Snipe-IT 测试邮件',
    'test_mail_text' => '这是一封 Snipe-IT 资产管理系统的测试电子邮件，如果您收到，表示邮件通知正常运作 :)',
    'the_following_item' => '以下项目已交回：',
    'low_inventory_alert' => '有：种物品已经低于或者接近最小库存。|有：种物品已经低于或者接近最小库存。',
    'assets_warrantee_alert' => '有：项资产的维保将在：天后到期。|有：项资产的维保将在：天后到期。',
    'license_expiring_alert' => '有：个许可将在：天后到期。|有：个许可将在：天后到期。',
    'to_reset' => '要重置 :web 的密码，请完成此表格：',
    'type' => '类型',
    'upcoming-audits' => '有:count 项资产将在:threshold 天内进行审计.|有:count 项资产将在:threshold 天内进行审计。',
    'user' => '用户',
    'username' => '用户名',
    'welcome' => '欢迎您，:name',
    'welcome_to' => '欢迎来到 :web！',
    'your_credentials' => '您的 Snipe-IT 登录凭据',
    'Accessory_Checkin_Notification' => '配件已签入',
    'Asset_Checkin_Notification' => '资产已签入',
    'License_Checkin_Notification' => '许可证已签入',
    'Expected_Checkin_Report' => '预期的资产检查报告',
    'Expected_Checkin_Notification' => '提醒：:name 签入截止日期已接近。',
    'Expected_Checkin_Date' => '借出的资产将在 :date 重新签入',
    'your_assets' => '查看您的资产'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/zh-CN/mail.php <==
<?php

return [
    'a_user_canceled' => '用户已取消物品申请',
    'a_user_requested' => '用户已申请物品',
    'accessory_name' => '配件名称：',
    'additional_notes' => '备注：',
    'admin_has_created' => '管理员已在 :web 为您新增帐号。',
    'asset' => '资产：',
    'asset_name' => '资产名称：',
    'asset_requested' => '已申请资产',
    'asset_tag' => '资产标签',
    'assigned_to' => '已分配给',
    'best_regards' => '此致',
    'canceled' => '已取消：',
    'checkin_date' => '交回日期：',
    'checkout_date' => '借出日期：',
    'click_to_confirm' => '请点击链接启用您在 :web 的帐号：',
    'click_on_the_link_accessory' => '请点击链接确认您已经收到配件。',
    'click_on_the_link_asset' => '请点击链接确认您已经收到资产。',
    'Confirm_Asset_Checkin' => '确认资产收回',
    'Confirm_Accessory_Checkin' => '配件签入确认',
    'Confirm_accessory_delivery' => '配件交付确认',
    'Confirm_license_delivery' => '许可证交付确认',
    'Confirm_asset_delivery' => '资产交付确认',
    'Confirm_consumable_delivery' => '耗材交付确认',
    'current_QTY' => '目前数量',
    'Days' => '天',
    'days' => '天',
    'expecting_checkin_date' => '预计归还日期：',
    'expires' => '过期',
    'Expiring_Assets_Report' => '过期资产报告',
    'Expiring_Licenses_Report' => '过期许可证报告',
    'hello' => '您好',
    'hi' => '您好',
    'i_have_read' => '我同意使用条款并确认已收到物品。',
    'item' => '项目：',
    'Item_Request_Canceled' => '已取消申领物品',
    'Item_Requested' => '已申领物品',
    'link_to_update_password' => '请点击以下链接以更新 :web 的密码：',
    'login_first_admin' => '请使用以下凭据登录新安装的 Snipe-IT：',
    'login' => '登录：',
    'Low_Inventory_Report' => '低库存报告',
    'min_QTY' => '最小数量',
    'name' => '名字',
    'new_item_checked' => '一项新物品已分配至您的名下，详细信息如下。',
    'password' => '密码',
    'password_reset' => '密码重置',

    'read_the_terms' => '请阅读以下使用条款',
    'read_the_terms_and_click' => '请阅读使用条款，点击下方链接确认您已阅读并同意使用条款，并已收到资产。',
    'requested' => '已申请',
    'reset_link' => '您的密码重置链接',
    'reset_password' => '请点击重置您的密码',
    'serial' => '序列号',
    'supplier' => '供应商',
    'tag' => '标签',
    'test_email' => 'Snipe-IT 测试邮件',
    'test_mail_text' => '这是一封 Snipe-IT 资产管理系统的测试电子邮件，如果您收到，表示邮件通知正常运作 :)',
    'the_following_item' => '以下项目已交回：',
    'low_inventory_alert' => '有：种物品已经低于或者接近最小库存。|有：种物品已经低于或者接近最小库存。',
    'assets_warrantee_alert' => '有 :count 个资产保修期将于 :threshold 天到期。|有 :count 个资产 保修期将于 :threshold 天到期。',
    'license_expiring_alert' => '有：个许可将在：天后到期。|有：个许可将在：天后到期。',
    'to_reset' => '要重置 :web 的密码，请完成此表格：',
    'type' => '类型',
    'upcoming-audits' => '有:count 项资产将在:threshold 天内进行审计.|有:count 项资产将在:threshold 天内进行审计。',
    'user' => '用户',
    'username' => '用户名',
    'welcome' => '欢迎您，:name',
    'welcome_to' => '欢迎来到 :web！',
    'your_credentials' => '您的 Snipe-IT 登录凭据',
    'Accessory_Checkin_Notification' => '配件已签入',
    'Asset_Checkin_Notification' => '资产已签入',
    'License_Checkin_Notification' => '许可证已签入',
    'Expected_Checkin_Report' => '预期的资产检查报告',
    'Expected_Checkin_Notification' => '提醒：:name 签入截止日期已接近。',
    'Expected_Checkin_Date' => '借出的资产将在 :date 重新签入',
    'your_assets' => '查看您的资产',
];
